lns.qtpynodeeditor\_patches package
=============================================

Submodules
----------

lns.qtpynodeeditor\_patches.auto\_layout\_extension module
--------------------------------------------------------------------

.. automodule:: lns.qtpynodeeditor_patches.auto_layout_extension
   :members:
   :undoc-members:
   :show-inheritance:

lns.qtpynodeeditor\_patches.connection\_draw\_fix module
------------------------------------------------------------------

.. automodule:: lns.qtpynodeeditor_patches.connection_draw_fix
   :members:
   :undoc-members:
   :show-inheritance:

lns.qtpynodeeditor\_patches.context\_menu module
----------------------------------------------------------

.. automodule:: lns.qtpynodeeditor_patches.context_menu
   :members:
   :undoc-members:
   :show-inheritance:

lns.qtpynodeeditor\_patches.multiple\_inputs module
-------------------------------------------------------------

.. automodule:: lns.qtpynodeeditor_patches.multiple_inputs
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lns.qtpynodeeditor_patches
   :members:
   :undoc-members:
   :show-inheritance:
